@@ -26,7 +26,7 @@ pub mod message {
         pub fn take_tcp_stream(index: u64) -> u64;
         pub fn send(process_id: u64);
         pub fn send_receive_skip_search(process_id: u64, timeout: u32) -> u32;
-        pub fn receive(tag: i64, timeout: u32) -> u32;
+        pub fn receive(tag: *const i64, tag_len: usize, timeout: u32) -> u32;
     }
 }
 
@@ -89,6 +89,7 @@ pub mod process {
         pub fn create_config(max_memory: u64, max_fuel: u64) -> u64;
         pub fn drop_config(config_id: u64);
         pub fn allow_namespace(config_id: u64, name: *const u8, name_len: usize);
+        pub fn preopen_dir(config_id: u64, dir: *const u8, dir_len: usize, id: *mut u64) -> u32;
         pub fn add_plugin(
             config_id: u64,
             plugin_data: *const u8,
@@ -96,6 +97,12 @@ pub mod process {
             id: *mut u64,
         ) -> u32;
         pub fn create_environment(config_id: u64, id: *mut u64) -> u32;
+        pub fn create_remote_environment(
+            config_id: u64,
+            node_name: *const u8,
+            node_name_len: usize,
+            id: *mut u64,
+        ) -> u32;
         pub fn drop_environment(env_id: u64);
         pub fn add_module(
             env_id: u64,
